Milestones — BAM - Blender Asset Manager 0.0.1 alpha documentation

# Milestones

## Minimum Viable Product

Get existing project migrated to asset manager as soon as possible.

- No Client-side-SVN.
- Checkout/Commit assets.
- Basic UI.
- ZIP file access (as an example, users wouldn’t have to notice)
- Testing (basic testing framework)

## Performance

- Parallel downloads
- Cache (avoid re-downloading files)

## Interface

- BAM project definition.
- Blender Addon (UI for performing basic actions)
- Maybe extend GUI client.
- Web UI
- Download Zipfiles

## Scaling/Project

- Consistency checks (correct library linking)

## Basic Automated Tasks

- Generated Previews (basic automated tasks hooked up to asset manager)
- Baking (physics)
- Web UI (create/view/manage jobs)

## Story Tool

- Establish connection between sequencer and ‘shot’ assets (abstract concept)
- Integrate into Addon
- Connect automated tasks on edit updates, (sync sequence with shot assets)
- Expose the edit outside of Blender (web based UI, reviews, comment, feedback, tasks...)

## Project Management

- Web UI
- Connect basic communication tools to assets, commits.